# A python base class for the cli program.

This is a simple example package. You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.

How to package this repo: refer to the following
1. create a pypi package
   [this link](https://packaging.python.org/tutorials/packaging-projects/) and [this link](https://datacadamia.com/lang/python/conda/pypi#about)
2. create an anaconda package
   [this link](https://docs.conda.io/projects/conda-build/en/latest/user-guide/tutorials/build-pkgs-skeleton.html)
